@@ -19,6 +19,7 @@
 # Boston, MA 02110-1301, USA.
 #
 
+
 from gnuradio import gr, gr_unittest, blocks, digital
 import pmt
 
@@ -33,7 +34,7 @@ class qa_crc32_bb(gr_unittest.TestCase):
 
     def test_001_crc_len(self):
         """ Make sure the output of a CRC set is 4 bytes longer than the input. """
-        data = range(16)
+        data = list(range(16))
         src = blocks.vector_source_b(data)
         crc = digital.crc32_bb(False, self.tsb_key)
         sink = blocks.tsb_vector_sink_b(tsb_key=self.tsb_key)
@@ -64,7 +65,7 @@ class qa_crc32_bb(gr_unittest.TestCase):
     def test_003_crc_correct_lentag(self):
         tag_name = "length"
         pack_len = 8
-        packets = range(pack_len * 2)
+        packets = list(range(pack_len*2))
         tag1 = gr.tag_t()
         tag1.offset = 0
         tag1.key = pmt.string_to_symbol(tag_name)
@@ -101,7 +102,7 @@ class qa_crc32_bb(gr_unittest.TestCase):
         tags_found = {'tag1': False, 'tag2': False, 'tag3': False}
         for tag in sink.tags():
             key = pmt.symbol_to_string(tag.key)
-            if key in correct_offsets.keys():
+            if key in list(correct_offsets.keys()):
                 tags_found[key] = True
                 self.assertEqual(correct_offsets[key], tag.offset)
         self.assertTrue(all(tags_found.values()))
@@ -147,7 +148,7 @@ class qa_crc32_bb(gr_unittest.TestCase):
 
     def test_006_crc_len(self):
         """ Make sure the output of a CRC set is 32 (unpacked) bytes longer than the input. """
-        data = range(16)
+        data = list(range(16))
         src = blocks.vector_source_b(data)
         crc = digital.crc32_bb(False, self.tsb_key, False)
         sink = blocks.tsb_vector_sink_b(tsb_key=self.tsb_key)
@@ -175,15 +176,13 @@ class qa_crc32_bb(gr_unittest.TestCase):
         # Check that the packets after crc_check are the same as input.
         self.assertEqual(data, sink.data()[0])
 
-    def test_002_crc_equal_unpacked(self):
+    def test_002_crc_equal_unpacked (self):
         """ Test unpacked operation with packed operation
         """
         data = (0, 1, 2, 3, 4, 5, 6, 7, 8)
         src = blocks.vector_source_b(data)
-        unpack1 = blocks.repack_bits_bb(8, 1, self.tsb_key, False,
-                                        gr.GR_LSB_FIRST)
-        unpack2 = blocks.repack_bits_bb(8, 1, self.tsb_key, False,
-                                        gr.GR_LSB_FIRST)
+        unpack1 = blocks.repack_bits_bb(8, 1, self.tsb_key, False, gr.GR_LSB_FIRST)
+        unpack2 = blocks.repack_bits_bb(8, 1, self.tsb_key, False, gr.GR_LSB_FIRST)
         crc_unpacked = digital.crc32_bb(False, self.tsb_key, False)
         crc_packed = digital.crc32_bb(False, self.tsb_key, True)
         sink1 = blocks.tsb_vector_sink_b(tsb_key=self.tsb_key)
@@ -225,10 +224,10 @@ class qa_crc32_bb(gr_unittest.TestCase):
         self.tb.run()
         self.assertEqual(sink1.data(), sink2.data())
 
-    def test_008_crc_correct_lentag(self):
+    def test_008_crc_correct_lentag (self):
         tag_name = "length"
         pack_len = 8
-        packets = range(pack_len * 2)
+        packets = list(range(pack_len*2))
         tag1 = gr.tag_t()
         tag1.offset = 0
         tag1.key = pmt.string_to_symbol(tag_name)
@@ -265,7 +264,7 @@ class qa_crc32_bb(gr_unittest.TestCase):
         tags_found = {'tag1': False, 'tag2': False, 'tag3': False}
         for tag in sink.tags():
             key = pmt.symbol_to_string(tag.key)
-            if key in correct_offsets.keys():
+            if key in list(correct_offsets.keys()):
                 tags_found[key] = True
                 self.assertEqual(correct_offsets[key], tag.offset)
         self.assertTrue(all(tags_found.values()))
@@ -289,11 +288,19 @@ class qa_crc32_bb(gr_unittest.TestCase):
     def test_0010_tag_propagation(self):
         """ Make sure tags on the CRC aren't lost. """
         # Data with precalculated CRC
-        data = (0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0,
-                0, 0, 0, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 1, 0,
-                1, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 0, 0, 0, 1, 1, 1, 0, 0, 0, 0,
-                0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0,
-                0, 0, 1, 0, 1, 0, 0, 0, 0, 1, 1, 1, 0, 0, 1, 1, 1, 1, 0, 1)
+        data = (0, 0, 0, 0, 0, 0, 0, 0,
+                1, 0, 0, 0, 0, 0, 0, 0,
+                0, 1, 0, 0, 0, 0, 0, 0,
+                1, 1, 0, 0, 0, 0, 0, 0,
+                0, 0, 1, 0, 0, 0, 0, 0,
+                1, 0, 1, 0, 0, 0, 0, 0,
+                0, 1, 1, 0, 0, 0, 0, 0,
+                1, 1, 1, 0, 0, 0, 0, 0,
+                0, 0, 0, 1, 0, 0, 0, 0,
+                0, 1, 0, 0, 0, 0, 0, 0,
+                1, 1, 0, 0, 0, 0, 1, 0,
+                1, 0, 0, 0, 0, 1, 1, 1,
+                0, 0, 1, 1, 1, 1, 0, 1)
         testtag = gr.tag_t()
         testtag.offset = len(data) - 1
         testtag.key = pmt.string_to_symbol('tag1')
